@@ -5,9 +5,13 @@ from unittest import TestCase
 from shutil   import rmtree
 from tempfile import mkdtemp
 
-from netcall.utils import setup_logger
+from netcall.utils import logger, setup_logger
 
-logger = setup_logger()
+from sys import argv
+if 'py.test' in argv[0]:
+    setup_logger(logger, level='DEBUG')
+else:
+    setup_logger(logger, level='WARNING')
 setup_logger('greenhouse')
 
 
